@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use 5.12.0;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
@@ -168,7 +168,7 @@ WWW::SFDC - Wrappers around the Salesforce.com APIs.
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -400,11 +400,11 @@ You can also look for information at L<https://github.com/alexander-brett/WWW-SF
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
