@@ -6,7 +6,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use Log::Log4perl ':easy';
 use SOAP::Lite;
@@ -104,7 +104,7 @@ WWW::SFDC::Apex - Interface to the salesforce.com Apex SOAP Api
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 METHODS
 
@@ -127,11 +127,11 @@ Unimplemented
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
