@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use List::Util 'first';
 use Log::Log4perl ':easy';
@@ -109,7 +109,7 @@ WWW::SFDC::Constants - Data about SFDC Metadata Components.
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 METHODS
 
@@ -127,11 +127,11 @@ version 0.33
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
