@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
@@ -117,12 +117,14 @@ sub _checkDeployment {
   my ($self, $id, $previous) = @_;
   LOGDIE "No ID was passed in" unless $id;
 
-  my $result = WWW::SFDC::Metadata::DeployResult->new(
-    result => $self->_call(
+  my ($request, $headers) = $self->_call(
       'checkDeployStatus',
       SOAP::Data->name("id" => $id),
       SOAP::Data->name("includeDetails" => "true")
-    )
+    );
+
+  my $result = WWW::SFDC::Metadata::DeployResult->new(
+    result => $request
   );
 
   if (scalar (my @errors = (
@@ -197,7 +199,7 @@ WWW::SFDC::Metadata - Interface to the Salesforce.com Metadata API
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -272,11 +274,11 @@ You can also look for information at L<https://github.com/alexander-brett/WWW-SF
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
