@@ -4,7 +4,7 @@ package WWW::SFDC::Metadata::DeployResult;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use Log::Log4perl ':easy';
 
@@ -143,15 +143,15 @@ WWW::SFDC::Metadata::DeployResult - Container for Salesforce Metadata API Deploy
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
