@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use List::NSect 'spart';
 use Log::Log4perl ':easy';
@@ -181,7 +181,7 @@ WWW::SFDC::Role::CRUD - Shared methods between partner and tooling APIs
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 METHODS
 
@@ -249,11 +249,11 @@ You can also look for information at L<https://github.com/alexander-brett/WWW-SF
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
