@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 use Moo::Role;
 use Module::Loaded;
@@ -57,7 +57,7 @@ WWW::SFDC::Role::SessionConsumer - Provides a transparent interface to WWW::SFDC
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -99,11 +99,11 @@ You can also look for information at L<https://github.com/alexander-brett/WWW-SF
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
